import requests

from .load_setting import load_setting


def get_url_with_id(url_param):
    """
    通过url获取id,使用华为云服务器，POST请求
    :param url_param:文档下载连接
    :return:id:str
    """
    # url = "http://127.0.0.1:8000/url_to_id/" # 本地测试url

    SETTING = load_setting()
    url = SETTING['url']['HuaweiCould Interface'] + 'url_to_id/'  # 线上运行url

    body = {"url": url_param}
    response = requests.post(url, json=body)
    data = response.json()
    if data['status'] == 'normal':
        return data['id']
    else:
        return "函数get_url_with_id出现错误，请检查输入的url_param是否正确"


def get_id_with_url(id):
    """
    通过id获取url,使用华为云服务器， GET请求
    :param id: 数据id
    :return: url:str
    """
    # url = "http://127.0.0.1:8000/id_to_url" # 本地测试url
    SETTING = load_setting()
    url = SETTING['url']['HuaweiCould Interface'] + "id_to_url/"  # 线上运行url
    response = requests.get(url + id)
    data = response.json()
    if data['status'] == 'normal':
        return data['url']
    else:
        return "函数get_id_with_url出现错误，请检查输入的id是否正确"



from .load_config import load_config
import pandas as pd

from .load_setting import load_setting

"""
加载数据集，用于后续处理
"""

def data_access(id:str):
    """
    获取数据集
    :param id: 数据id
    :return: pandas.DataFrame 返回数据集
    """
    SETTING = load_setting()
    config = load_config(id)

    data_file = config["dataset"]["data_files"][0]  # 获取数据集data.csv，默认当前只有一个数据集文件
    data = pd.read_csv(f'{SETTING["base_path"]}/repo_{id}/{data_file["file_name"]}', sep=data_file["sep"])
    return data
